package com.link.core.basic.aop;

import com.link.base.user.model.CoreUser;
import com.link.core.util.BeanTools;
import com.link.core.util.StringUtils;
import com.link.core.util.UserUtil;
import java.lang.reflect.Method;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.stereotype.Service;

public class MultiCorpServiceAspect {
   @Pointcut("execution(* com.link.base..service..*.*(..)) || execution(* com.link.core.basic.service..*.*(..))")
   public void multiCorpService() {
   }

   @Around("multiCorpService()")
   public Object daoPointcut(ProceedingJoinPoint point) throws Throwable {
      CoreUser user = null;

      try {
         user = UserUtil.getUser();
      } catch (Exception var10) {
      }

      if (user == null) {
         return point.proceed();
      } else {
         Long corpId = user.getLoginCorpId();
         if (null == corpId) {
            return point.proceed();
         } else {
            Object target = point.getTarget();
            Object corpService = this.getCorpServiceBean(target, corpId);
            if (corpService == null) {
               return point.proceed();
            } else {
               Class<?>[] parameterTypes = ((MethodSignature)point.getSignature()).getMethod().getParameterTypes();
               String method = point.getSignature().getName();
               Method targetMethod = corpService.getClass().getMethod(method, parameterTypes);
               Object resultObj = targetMethod.invoke(corpService, point.getArgs());
               return resultObj;
            }
         }
      }
   }

   private Object getCorpServiceBean(Object serviceObj, Long corpId) throws Exception {
      Service annotation = (Service)serviceObj.getClass().getAnnotation(Service.class);
      if (annotation == null) {
         return null;
      } else {
         String serviceSymbol = "Service";
         String standardBeanName = annotation.value();
         if (StringUtils.isBlank(standardBeanName)) {
            return null;
         } else {
            StringBuilder sb = new StringBuilder(standardBeanName);
            if (standardBeanName.endsWith("Service")) {
               sb.insert(sb.lastIndexOf("Service"), "C" + corpId);
            }

            String corpBeanName = sb.toString();
            Object corpService = BeanTools.getBean(corpBeanName);
            return corpService;
         }
      }
   }
}
